==> data_mine-0.0.4.tar.gz: data_mine-0.0.4/README.md <==
# Data Mine

<p align="center">
  <img width="42%" height="42%" src="https://github.com/SebiSebi/DataMine/blob/master/images/logo/goldmine_logo_v1.png">
</p>

[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://github.com/SebiSebi/DataMine/blob/master/LICENSE)
[![Build Status](https://travis-ci.com/SebiSebi/DataMine.svg?branch=master)](https://travis-ci.com/github/SebiSebi/DataMine)
[![codecov](https://codecov.io/gh/SebiSebi/DataMine/branch/master/graph/badge.svg)](https://codecov.io/gh/SebiSebi/DataMine)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/95f452694b2644ca9f30f5d39379de91)](https://www.codacy.com/manual/SebiSebi/DataMine?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=SebiSebi/DataMine&amp;utm_campaign=Badge_Grade)

[![Python Versions](https://img.shields.io/badge/python-2.7%20%7C%203.5%20%7C%203.6%20%7C%203.7%20%7C%203.8-blue)](https://pypi.org/project/data-mine/)

Available datasets
------------------

| Dataset             | Keywords                   | Usage & Detailed Info                   | Example(s)                      |
| ------------------- | -------------------------- | --------------------------------------- | ------------------------------- |
| `RACE`              | NLP, QA, Multiple Choice   | [Additional information][RACE-Home]     | [RACE Example][RACE-Example-1]  |


[RACE-Home]: https://github.com/SebiSebi/DataMine/tree/master/data_mine/nlp/RACE
[RACE-Example-1]: https://github.com/SebiSebi/DataMine/blob/master/examples/nlp/RACE/simple.py

==> data_mine-0.0.7.tar.gz: data_mine-0.0.7/README.md <==
# Data Mine

<p align="center">
  <img width="42%" height="42%" src="https://github.com/SebiSebi/DataMine/blob/master/images/logo/goldmine_logo_v1.png">
</p>

[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://github.com/SebiSebi/DataMine/blob/master/LICENSE)
[![Build Status](https://travis-ci.com/SebiSebi/DataMine.svg?branch=master)](https://travis-ci.com/github/SebiSebi/DataMine)
[![codecov](https://codecov.io/gh/SebiSebi/DataMine/branch/master/graph/badge.svg)](https://codecov.io/gh/SebiSebi/DataMine)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/95f452694b2644ca9f30f5d39379de91)](https://www.codacy.com/manual/SebiSebi/DataMine?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=SebiSebi/DataMine&amp;utm_campaign=Badge_Grade)

[![Python Versions](https://img.shields.io/badge/python-2.7%20%7C%203.5%20%7C%203.6%20%7C%203.7%20%7C%203.8-blue)](https://pypi.org/project/data-mine/)

Available datasets
------------------

| Dataset               | Keywords                   | Usage & Detailed Info                   | Example(s)                      |
| --------------------- | -------------------------- | --------------------------------------- | ------------------------------- |
| `RACE`                | NLP, QA, Multiple Choice   | [Additional information][RACE-Home]     | [RACE Example][RACE-Example-1]  |
| `AllenAI OpenBookQA`  | NLP, QA, Multiple Choice   | [Additional information][OBQA-Home]     | [OBQA Example][OBQA-Example-1]  |



[RACE-Home]: https://github.com/SebiSebi/DataMine/tree/master/data_mine/nlp/RACE
[RACE-Example-1]: https://github.com/SebiSebi/DataMine/blob/master/examples/nlp/RACE/simple.py
[OBQA-Home]: https://github.com/SebiSebi/DataMine/tree/master/data_mine/nlp/allen_ai_obqa
[OBQA-Example-1]: https://github.com/SebiSebi/DataMine/blob/master/examples/nlp/allen_ai_obqa/simple.py
